@@ -81,7 +81,60 @@ class ROHSA(object):
                 f.write(line)
 
         
-    def gen_parameters(self, filename_parameters=None, filename=None, fileout="result.dat", timeout="timestep.dat", filename_noise="", filename_init_spec="", 
+    def gen_parameters(self, filename_parameters=None, filename=None, fileout="result.dat", timeout="timestep.dat", filename_noise="", 
+                       n_gauss=3, lambda_amp=1000, lambda_mu=1000, lambda_sig=1000, lambda_var_amp=0, lambda_var_mu=0, lambda_var_sig=1000, lambda_lym_sig=0, 
+                       amp_fact_init=0.66, sig_init = 4., lb_sig_init=1., ub_sig_init=100., lb_sig=0.001, ub_sig=100., init_option="mean", maxiter_init=15000, 
+                       maxiter=800, m=10, noise=".false.", regul = ".true.", descent = ".true.", lstd = 1, ustd = 20, iprint = -1, iprint_init = -1, 
+                       save_grid=".true.", lym=".false."):
+
+        if not filename : 
+            print("Need an input filename")
+            sys.exit()
+
+        if not filename_parameters :
+            print("Generate parameters.txt file")
+        else: print("Generate " + filename_parameters + " file")
+        
+        filename_parameters = filename_parameters or "parameters.txt"
+
+        input_file = open(filename_parameters, 'w')
+        input_file.write("&user_parameters"+'\n')
+        input_file.write("    filename =  "+repr(filename)+'\n')
+        input_file.write("    ,fileout =  "+repr(fileout)+'\n')
+        input_file.write("    ,timeout =  "+repr(timeout)+'\n')
+        input_file.write("    ,filename_noise =  "+repr(filename_noise)+'\n')
+        input_file.write("    ,n_gauss =  "+repr(n_gauss)+'\n')
+        input_file.write("    ,lambda_amp =  "+repr(lambda_amp)+'d0'+'\n')
+        input_file.write("    ,lambda_mu =  "+repr(lambda_mu)+'d0'+'\n')
+        input_file.write("    ,lambda_sig =  "+repr(lambda_sig)+'d0'+'\n')
+        input_file.write("    ,lambda_var_amp =  "+repr(lambda_var_amp)+'d0'+'\n')
+        input_file.write("    ,lambda_var_mu =  "+repr(lambda_var_mu)+'d0'+'\n')
+        input_file.write("    ,lambda_var_sig =  "+repr(lambda_var_sig)+'d0'+'\n')
+        input_file.write("    ,lambda_lym_sig =  "+repr(lambda_lym_sig)+'d0'+'\n')
+        input_file.write("    ,amp_fact_init =  "+repr(amp_fact_init)+'d0'+'\n')
+        input_file.write("    ,sig_init =  "+repr(sig_init)+'d0'+'\n')
+        input_file.write("    ,lb_sig_init =  "+repr(lb_sig_init)+'d0'+'\n')
+        input_file.write("    ,ub_sig_init =  "+repr(ub_sig_init)+'d0'+'\n')
+        input_file.write("    ,lb_sig =  "+repr(lb_sig)+'d0'+'\n')
+        input_file.write("    ,ub_sig =  "+repr(ub_sig)+'d0'+'\n')
+        input_file.write("    ,init_option =  "+repr(init_option)+'\n')
+        input_file.write("    ,maxiter_init =  "+repr(maxiter_init)+'\n')
+        input_file.write("    ,maxiter =  "+repr(maxiter)+'\n')
+        input_file.write("    ,m =  "+repr(m)+'\n')
+        input_file.write("    ,noise =  "+noise+'\n')
+        input_file.write("    ,regul =  "+regul+'\n')
+        input_file.write("    ,descent =  "+descent+'\n')
+        input_file.write("    ,lstd =  "+repr(lstd)+'\n')
+        input_file.write("    ,ustd =  "+repr(ustd)+'\n')
+        input_file.write("    ,iprint =  "+repr(iprint)+'\n')
+        input_file.write("    ,iprint_init =  "+repr(iprint_init)+'\n')
+        input_file.write("    ,save_grid =  "+save_grid+'\n')
+        input_file.write("    ,lym =  "+lym+'\n')
+        input_file.write("    /"+'\n')
+        input_file.close()
+
+
+    def gen_parameters_3D(self, filename_parameters=None, filename=None, fileout="result.dat", timeout="timestep.dat", filename_noise="", filename_init_spec="", 
                        n_gauss=3, lambda_amp=1000, lambda_mu=1000, lambda_sig=1000, lambda_var_amp=0, lambda_var_mu=0, lambda_var_sig=1000, lambda_lym_sig=0, 
                        amp_fact_init=0.66, sig_init = 4., lb_sig_init=1., ub_sig_init=100., lb_sig=0.001, ub_sig=100., init_option="mean", maxiter_init=15000, 
                        maxiter=800, m=10, noise=".false.", regul = ".true.", descent = ".true.", lstd = 1, ustd = 20, iprint = -1, iprint_init = -1, 
